/*
 * SavingsAccount.java
 *
 * XXX note that this code does NOT consider Year.
 */
import java.util.*;

public class SavingsAccount extends Account {

	int	monthOfWithdraw; // the month in which last withdraw was made
	int	numOfWithdraws; // num of withdraws made this month

  public SavingsAccount( String owner )
  {
    this(owner,0.0);
  }

  public SavingsAccount( String owner, double balance )
  {
    super( owner, balance );
    monthOfWithdraw = -1;
    numOfWithdraws = 0;
  }

  /**
   * overrides the withdraw method in the superclass. returns the
   * actual amount withdrawn.
   */
  public double withdraw( double amount )
  {
    // get the current month
    GregorianCalendar gc = new GregorianCalendar();
    int month = gc.get( Calendar.MONTH );

    // if this month is different from the month of last withdraw,
    // this withdraw is allowed and we should set the number of
    // withdraws to 1
    if( month != monthOfWithdraw )
    {
      monthOfWithdraw = month;
      numOfWithdraws = 1;
      return super.withdraw(amount);
    }
    // if this month is the same as the month of last withdraw,
    // we need to check how many withdraws have been made
    else
    {
      if( numOfWithdraws == 2 ) return 0;
      else
      {
        ++numOfWithdraws;
        return super.withdraw(amount);
      }
    }
  }

  // overrides the toString method in Account
  public String toString()
  {
    String s = super.toString();
    s += "\n\tMonth of Last Withdraw:\t" + (monthOfWithdraw+1) +
         "\n\tNumber of Withdraws:\t" + numOfWithdraws;
    return s;
  }

  // testing
  public static void main( String args[] )
  {
    SavingsAccount s = new SavingsAccount( "csun" );
    s.deposit(100.0);
    System.out.println( s );
    s.withdraw(20.0);
    System.out.println( s );
    s.withdraw(10.0);
    System.out.println( s );
    s.withdraw(15.0);
    System.out.println( s );
  }

} // end of class SavingsAccount

